pub enum BytesType<'a> {
Bytes(RustyPyBytes<'a>),
ByteArray(RustyPyByteArray<'a>),
RustyFile(&'a PyCell<RustyFile>),
RustyBuffer(&'a PyCell<RustyBuffer>),
NumpyArray(RustyNumpyArray<'a>),
}Expand description
Any possible input/output to de/compression algorithms. Typically, as a Python user, you never have to worry about this object. It’s exposed here in the documentation to see what types are acceptable for de/compression functions.
Variants
Bytes(RustyPyBytes<'a>)
bytes
ByteArray(RustyPyByteArray<'a>)
bytearray
RustyFile(&'a PyCell<RustyFile>)
RustyBuffer(&'a PyCell<RustyBuffer>)
NumpyArray(RustyNumpyArray<'a>)
numpy.array with dtype=np.uint8