pub struct CompressionError(/* private fields */);Implementations
Methods from Deref<Target = PyAny>
Sourcepub fn downcast<T>(&self) -> Result<&T, PyDowncastError<'_>>where
T: for<'py> PyTryFrom<'py>,
pub fn downcast<T>(&self) -> Result<&T, PyDowncastError<'_>>where
T: for<'py> PyTryFrom<'py>,
Converts this PyAny to a concrete Python type.
Examples
use pyo3::prelude::*;
use pyo3::types::{PyAny, PyDict, PyList};
Python::with_gil(|py| {
let dict = PyDict::new(py);
assert!(dict.is_instance::<PyAny>().unwrap());
let any: &PyAny = dict.as_ref();
assert!(any.downcast::<PyDict>().is_ok());
assert!(any.downcast::<PyList>().is_err());
});Sourcepub fn hasattr<N>(&self, attr_name: N) -> Result<bool, PyErr>where
N: ToPyObject,
pub fn hasattr<N>(&self, attr_name: N) -> Result<bool, PyErr>where
N: ToPyObject,
Determines whether this object has the given attribute.
This is equivalent to the Python expression hasattr(self, attr_name).
Sourcepub fn getattr<N>(&self, attr_name: N) -> Result<&PyAny, PyErr>where
N: ToPyObject,
pub fn getattr<N>(&self, attr_name: N) -> Result<&PyAny, PyErr>where
N: ToPyObject,
Retrieves an attribute value.
This is equivalent to the Python expression self.attr_name.
Sourcepub fn setattr<N, V>(&self, attr_name: N, value: V) -> Result<(), PyErr>where
N: ToBorrowedObject,
V: ToBorrowedObject,
pub fn setattr<N, V>(&self, attr_name: N, value: V) -> Result<(), PyErr>where
N: ToBorrowedObject,
V: ToBorrowedObject,
Sets an attribute value.
This is equivalent to the Python expression self.attr_name = value.
Sourcepub fn delattr<N>(&self, attr_name: N) -> Result<(), PyErr>where
N: ToPyObject,
pub fn delattr<N>(&self, attr_name: N) -> Result<(), PyErr>where
N: ToPyObject,
Deletes an attribute.
This is equivalent to the Python statement del self.attr_name.
Sourcepub fn compare<O>(&self, other: O) -> Result<Ordering, PyErr>where
O: ToPyObject,
pub fn compare<O>(&self, other: O) -> Result<Ordering, PyErr>where
O: ToPyObject,
Returns an Ordering between self and other.
This is equivalent to the following Python code:
if self == other:
return Equal
elif a < b:
return Less
elif a > b:
return Greater
else:
raise TypeError("PyAny::compare(): All comparisons returned false")Examples
use pyo3::prelude::*;
use pyo3::types::PyFloat;
use std::cmp::Ordering;
Python::with_gil(|py| -> PyResult<()> {
let a = PyFloat::new(py, 0_f64);
let b = PyFloat::new(py, 42_f64);
assert_eq!(a.compare(b)?, Ordering::Less);
Ok(())
})?;It will return PyErr for values that cannot be compared:
use pyo3::prelude::*;
use pyo3::types::{PyFloat, PyString};
Python::with_gil(|py| -> PyResult<()> {
let a = PyFloat::new(py, 0_f64);
let b = PyString::new(py, "zero");
assert!(a.compare(b).is_err());
Ok(())
})?;Sourcepub fn rich_compare<O>(
&self,
other: O,
compare_op: CompareOp,
) -> Result<&PyAny, PyErr>where
O: ToPyObject,
pub fn rich_compare<O>(
&self,
other: O,
compare_op: CompareOp,
) -> Result<&PyAny, PyErr>where
O: ToPyObject,
Tests whether two Python objects obey a given CompareOp.
Depending on the value of compare_op, this is equivalent to one of the
following Python expressions:
compare_op | Python expression |
|---|---|
CompareOp::Eq | self == other |
CompareOp::Ne | self != other |
CompareOp::Lt | self < other |
CompareOp::Le | self <= other |
CompareOp::Gt | self > other |
CompareOp::Ge | self >= other |
Examples
use pyo3::prelude::*;
use pyo3::types::PyInt;
use pyo3::class::basic::CompareOp;
Python::with_gil(|py| -> PyResult<()> {
let a: &PyInt = 0_u8.into_py(py).into_ref(py).downcast()?;
let b: &PyInt = 42_u8.into_py(py).into_ref(py).downcast()?;
assert!(a.rich_compare(b, CompareOp::Le)?.is_true()?);
Ok(())
})?;Sourcepub fn is_callable(&self) -> bool
pub fn is_callable(&self) -> bool
Determines whether this object appears callable.
This is equivalent to Python’s callable() function.
Examples
use pyo3::prelude::*;
Python::with_gil(|py| -> PyResult<()> {
let builtins = PyModule::import(py, "builtins")?;
let print = builtins.getattr("print")?;
assert!(print.is_callable());
Ok(())
})?;This is equivalent to the Python statement assert callable(print).
Note that unless an API needs to distinguish between callable and non-callable objects, there is no point in checking for callability. Instead, it is better to just do the call and handle potential exceptions.
Sourcepub fn call(
&self,
args: impl IntoPy<Py<PyTuple>>,
kwargs: Option<&PyDict>,
) -> Result<&PyAny, PyErr>
pub fn call( &self, args: impl IntoPy<Py<PyTuple>>, kwargs: Option<&PyDict>, ) -> Result<&PyAny, PyErr>
Calls the object.
This is equivalent to the Python expression self(*args, **kwargs).
Sourcepub fn call0(&self) -> Result<&PyAny, PyErr>
pub fn call0(&self) -> Result<&PyAny, PyErr>
Calls the object without arguments.
This is equivalent to the Python expression self().
Examples
use pyo3::prelude::*;
Python::with_gil(|py| -> PyResult<()> {
let module = PyModule::import(py, "builtins")?;
let help = module.getattr("help")?;
help.call0()?;
Ok(())
})?;This is equivalent to the Python expression help().
Sourcepub fn call1(&self, args: impl IntoPy<Py<PyTuple>>) -> Result<&PyAny, PyErr>
pub fn call1(&self, args: impl IntoPy<Py<PyTuple>>) -> Result<&PyAny, PyErr>
Calls the object with only positional arguments.
This is equivalent to the Python expression self(*args).
Examples
use pyo3::prelude::*;
Python::with_gil(|py| -> PyResult<()> {
let module = PyModule::import(py, "operator")?;
let add = module.getattr("add")?;
let args = (1,2);
let value = add.call1(args)?;
assert_eq!(value.extract::<i32>()?, 3);
Ok(())
})?;This is equivalent to the following Python code:
from operator import add
value = add(1,2)
assert value == 3Sourcepub fn call_method(
&self,
name: &str,
args: impl IntoPy<Py<PyTuple>>,
kwargs: Option<&PyDict>,
) -> Result<&PyAny, PyErr>
pub fn call_method( &self, name: &str, args: impl IntoPy<Py<PyTuple>>, kwargs: Option<&PyDict>, ) -> Result<&PyAny, PyErr>
Calls a method on the object.
This is equivalent to the Python expression self.name(*args, **kwargs).
Examples
use pyo3::prelude::*;
use pyo3::types::{PyDict, PyList};
use crate::pyo3::types::IntoPyDict;
Python::with_gil(|py| -> PyResult<()> {
let list = PyList::new(py, vec![3, 6, 5, 4, 7]);
let kwargs = vec![("reverse", true)].into_py_dict(py);
list.call_method("sort", (), Some(kwargs))?;
assert_eq!(list.extract::<Vec<i32>>()?, vec![7, 6, 5, 4, 3]);
Ok(())
})?;This is equivalent to the following Python code:
my_list = [3, 6, 5, 4, 7]
my_list.sort(reverse = True)
assert my_list == [7, 6, 5, 4, 3]Sourcepub fn call_method0(&self, name: &str) -> Result<&PyAny, PyErr>
pub fn call_method0(&self, name: &str) -> Result<&PyAny, PyErr>
Calls a method on the object without arguments.
This is equivalent to the Python expression self.name().
Examples
use pyo3::prelude::*;
use pyo3::types::PyFloat;
use std::f64::consts::PI;
Python::with_gil(|py| -> PyResult<()> {
let pi = PyFloat::new(py, PI);
let ratio = pi.call_method0("as_integer_ratio")?;
let (a, b) = ratio.extract::<(u64, u64)>()?;
assert_eq!(a, 884_279_719_003_555);
assert_eq!(b, 281_474_976_710_656);
Ok(())
})?;This is equivalent to the following Python code:
import math
a, b = math.pi.as_integer_ratio()Sourcepub fn call_method1(
&self,
name: &str,
args: impl IntoPy<Py<PyTuple>>,
) -> Result<&PyAny, PyErr>
pub fn call_method1( &self, name: &str, args: impl IntoPy<Py<PyTuple>>, ) -> Result<&PyAny, PyErr>
Calls a method on the object with only positional arguments.
This is equivalent to the Python expression self.name(*args).
Examples
use pyo3::prelude::*;
use pyo3::types::PyList;
Python::with_gil(|py| -> PyResult<()> {
let list = PyList::new(py, vec![1, 3, 4]);
list.call_method1("insert", (1, 2))?;
assert_eq!(list.extract::<Vec<u8>>()?, [1, 2, 3, 4]);
Ok(())
})?;This is equivalent to the following Python code:
list_ = [1,3,4]
list_.insert(1,2)
assert list_ == [1,2,3,4]Sourcepub fn is_true(&self) -> Result<bool, PyErr>
pub fn is_true(&self) -> Result<bool, PyErr>
Returns whether the object is considered to be true.
This is equivalent to the Python expression bool(self).
Sourcepub fn is_none(&self) -> bool
pub fn is_none(&self) -> bool
Returns whether the object is considered to be None.
This is equivalent to the Python expression self is None.
Sourcepub fn is_empty(&self) -> Result<bool, PyErr>
pub fn is_empty(&self) -> Result<bool, PyErr>
Returns true if the sequence or mapping has a length of 0.
This is equivalent to the Python expression len(self) == 0.
Sourcepub fn get_item<K>(&self, key: K) -> Result<&PyAny, PyErr>where
K: ToBorrowedObject,
pub fn get_item<K>(&self, key: K) -> Result<&PyAny, PyErr>where
K: ToBorrowedObject,
Gets an item from the collection.
This is equivalent to the Python expression self[key].
Sourcepub fn set_item<K, V>(&self, key: K, value: V) -> Result<(), PyErr>where
K: ToBorrowedObject,
V: ToBorrowedObject,
pub fn set_item<K, V>(&self, key: K, value: V) -> Result<(), PyErr>where
K: ToBorrowedObject,
V: ToBorrowedObject,
Sets a collection item value.
This is equivalent to the Python expression self[key] = value.
Sourcepub fn del_item<K>(&self, key: K) -> Result<(), PyErr>where
K: ToBorrowedObject,
pub fn del_item<K>(&self, key: K) -> Result<(), PyErr>where
K: ToBorrowedObject,
Deletes an item from the collection.
This is equivalent to the Python expression del self[key].
Sourcepub fn iter(&self) -> Result<&PyIterator, PyErr>
pub fn iter(&self) -> Result<&PyIterator, PyErr>
Takes an object and returns an iterator for it.
This is typically a new iterator but if the argument is an iterator, this returns itself.
Sourcepub fn get_type_ptr(&self) -> *mut PyTypeObject
pub fn get_type_ptr(&self) -> *mut PyTypeObject
Returns the Python type pointer for this object.
Sourcepub fn cast_as<'a, D>(&'a self) -> Result<&'a D, PyDowncastError<'a>>where
D: PyTryFrom<'a>,
pub fn cast_as<'a, D>(&'a self) -> Result<&'a D, PyDowncastError<'a>>where
D: PyTryFrom<'a>,
Casts the PyObject to a concrete Python object type.
This can cast only to native Python types, not types implemented in Rust.
Sourcepub fn extract<'a, D>(&'a self) -> Result<D, PyErr>where
D: FromPyObject<'a>,
pub fn extract<'a, D>(&'a self) -> Result<D, PyErr>where
D: FromPyObject<'a>,
Extracts some type from the Python object.
This is a wrapper function around FromPyObject::extract().
Sourcepub fn get_refcnt(&self) -> isize
pub fn get_refcnt(&self) -> isize
Returns the reference count for the Python object.
Sourcepub fn repr(&self) -> Result<&PyString, PyErr>
pub fn repr(&self) -> Result<&PyString, PyErr>
Computes the “repr” representation of self.
This is equivalent to the Python expression repr(self).
Sourcepub fn str(&self) -> Result<&PyString, PyErr>
pub fn str(&self) -> Result<&PyString, PyErr>
Computes the “str” representation of self.
This is equivalent to the Python expression str(self).
Sourcepub fn hash(&self) -> Result<isize, PyErr>
pub fn hash(&self) -> Result<isize, PyErr>
Retrieves the hash code of self.
This is equivalent to the Python expression hash(self).
Sourcepub fn len(&self) -> Result<usize, PyErr>
pub fn len(&self) -> Result<usize, PyErr>
Returns the length of the sequence or mapping.
This is equivalent to the Python expression len(self).
Sourcepub fn dir(&self) -> &PyList
pub fn dir(&self) -> &PyList
Returns the list of attributes of this object.
This is equivalent to the Python expression dir(self).
Sourcepub fn is_instance<T>(&self) -> Result<bool, PyErr>where
T: PyTypeObject,
pub fn is_instance<T>(&self) -> Result<bool, PyErr>where
T: PyTypeObject,
Checks whether this object is an instance of type T.
This is equivalent to the Python expression isinstance(self, T).